@@ -10,7 +10,7 @@
 aggregateDist <-
     function(method = c("recursive", "convolution", "normal", "npower", "simulation"),
              model.freq = NULL, model.sev = NULL, p0 = NULL, x.scale = 1,
-             moments, nb.simul, ..., TOL = 1e-06, echo = FALSE)
+             moments, nb.simul, ..., tol = 1e-06, maxit = 500, echo = FALSE)
 {
     Call <- match.call()
 
@@ -66,7 +66,8 @@ aggregateDist <-
                               c("poisson", "geometric", "negative binomial",
                                 "binomial", "logarithmic"))
             FUN <- panjer(fx = model.sev, dist = dist, p0 = p0,
-                          x.scale = x.scale, ..., echo = echo, TOL = TOL)
+                          x.scale = x.scale, ...,
+                          tol = tol, maxit = maxit, echo = echo)
             comment(FUN) <- "Recursive method approximation"
         }
 
@@ -85,7 +86,7 @@ aggregateDist <-
 
     ## Return cumulative distribution function
     class(FUN) <- c("aggregateDist", class(FUN))
-    assign("Call", Call, environment(FUN))
+    attr(FUN, "call") <- Call
     FUN
 }
 
@@ -95,21 +96,21 @@ print.aggregateDist <- function(x, ...)
     cat("  ", label <- comment(x), "\n\n", sep = "")
 
     cat("Call:\n")
-    print(get("Call", envir = environment(x)))
+    print(attr(x, "call"))
     cat("\n")
 
     if (label %in% c("Exact calculation (convolutions)",
                      "Recursive method approximation",
                      "Approximation by simulation"))
     {
-        n <- length(get("x", environment(x)))
+        n <- length(get("x", envir = environment(x)))
         cat("Data:  (", n, "obs. )\n")
         numform <- function(x) paste(formatC(x, dig = 4, width = 5), collapse = ", ")
         i1 <- 1:min(3, n)
         i2 <- if (n >= 4)
             max(4, n - 1):n
         else integer(0)
-        xx <- eval(expression(x), env = environment(x))
+        xx <- eval(expression(x), envir = environment(x))
         cat(" x[1:", n, "] = ", numform(xx[i1]), if (n > 3)
         ", ", if (n > 5)
         " ..., ", numform(xx[i2]), "\n", sep = "")
@@ -118,9 +119,7 @@ print.aggregateDist <- function(x, ...)
     if (label %in% c("Normal approximation",
                      "Normal Power approximation"))
         cat(attr(x, "source"), "\n")
-    print(environment(x))
-    cat("Class attribute:\n")
-    print(attr(x, "class"))
+    invisible(x)
 }
 
 plot.aggregateDist <- function(x, xlim,
@@ -141,13 +140,13 @@ plot.aggregateDist <- function(x, xlim,
         ## in argument.
         if (missing(xlim))
         {
-            mean <- get("mean", environment(x))
-            sd <- sqrt(get("variance", environment(x)))
+            mean <- get("mean", envir = environment(x))
+            sd <- sqrt(get("variance", envir = environment(x)))
             xlim <- c(mean - 3 * sd, mean + 3 * sd)
         }
         curve(x, main = main, ylab = ylab, xlim = xlim, ylim = c(0, 1), ...)
     }
-    mtext(sub)
+    mtext(sub, line = 0.5)
 }
 
 summary.aggregateDist <- function(object, ...)
@@ -175,6 +174,7 @@ print.summary.aggregateDist <- function(x, ...)
     res <- c(min, q[c(1, 2)], expectation, q[3], max)
     names(res) <- c("Min.", "1st Qu.", "Median", "Mean", "3rd Qu.", "Max.")
     print(res)
+    invisible(x)
 }
 
 mean.aggregateDist <- function(x, ...)
@@ -185,16 +185,11 @@ mean.aggregateDist <- function(x, ...)
     ## the case of the Normal and Normal Power approximations.
     if (label %in%
         c("Normal approximation", "Normal Power approximation"))
-        return(get("mean", environment(x)))
+        return(get("mean", envir = environment(x)))
 
     ## For the recursive, exact and simulation methods, compute the
-    ## mean from the stepwise cdf. For the first two, use the pmf
-    ## saved in the environment of the object.
-    val <- get("x", environment(x))
-    prob <-
-        if (label == "Approximation by simulation")
-            c(val[1], diff(get("y", environment(x))))
-        else
-            get("fs", environment(x))
-    drop(crossprod(val, prob))
+    ## mean from the stepwise cdf using the pmf saved in the
+    ## environment of the object.
+    drop(crossprod(get("x", envir = environment(x)),
+                   get("fs", envir = environment(x))))
 }
